@@ -11,7 +11,7 @@
 #' cut_quanti(cgd$height, 3)
 
 cut_quanti=function(x,n,...){
-  out=cut(x,breaks=quantile(x,probs=seq(0,1,length=n+1)),include.lowest=TRUE,...)
+  out=cut(x,breaks=quantile(x,probs=seq(0,1,length=n+1),na.rm=TRUE),include.lowest=TRUE,...)
   return(out)
 }
 
